
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "polkitauthorityfeatures.h" */

GType polkit_authority_features_get_type (void);
#define POLKIT_TYPE_AUTHORITY_FEATURES (polkit_authority_features_get_type())

/* enumerations from "polkitcheckauthorizationflags.h" */

GType polkit_check_authorization_flags_get_type (void);
#define POLKIT_TYPE_CHECK_AUTHORIZATION_FLAGS (polkit_check_authorization_flags_get_type())

/* enumerations from "polkiterror.h" */

GType polkit_error_get_type (void);
#define POLKIT_TYPE_ERROR (polkit_error_get_type())

/* enumerations from "polkitimplicitauthorization.h" */

GType polkit_implicit_authorization_get_type (void);
#define POLKIT_TYPE_IMPLICIT_AUTHORIZATION (polkit_implicit_authorization_get_type())

G_END_DECLS

/* Generated data ends here */

